@@ -422,15 +422,35 @@ class yFinanceSource(YfinanceBase, AbstractSource):
     def _read_series(  # type: ignore
         self, tickers: List[str], type: SeriesLength
     ) -> List[yFinancePrice]:
-        data = yf.download(tickers, period=type, group_by="ticker", auto_adjust=True)
+        data = yf.download(
+            tickers, period=type, group_by="ticker", auto_adjust=True, timeout=60
+        )
+        if any(data[(ticker, "Close")].empty for ticker in tickers):
+            data = yf.download(
+                tickers, period=type, group_by="ticker", auto_adjust=True, timeout=60
+            )
+
         records_final = []
         for ticker in tickers:
-            if ticker in data.columns:
-                records = data[ticker].reset_index().to_dict(orient="records")
-                records_final.extend(
-                    [
-                        yFinancePrice(**(record | {"symbol": ticker}))
-                        for record in records
-                    ]
-                )
+            try:
+                if ticker in data.columns:
+                    records = data[ticker].reset_index().to_dict(orient="records")
+                    if not records:
+                        logger.error(f"No data found for ticker: {ticker}")
+                    records_final.extend(
+                        [
+                            yFinancePrice(
+                                **(
+                                    record
+                                    | {
+                                        "symbol": ticker,
+                                        "Date": pd.to_datetime(record["Date"]).date(),
+                                    }
+                                )
+                            )
+                            for record in records
+                        ]
+                    )
+            except Exception as e:  # noqa: PERF203
+                logger.error(f"Error reading series for {ticker}: {e}")
         return records_final
